SynthResult class
Bundle returned by StackSynth.synth.
Constructors
-
SynthResult({required Map<
String, dynamic> tfJson, required String? dartSource, required String? dartSourcePath}) -
const
Properties
- dartSource → String?
-
Generated Dart source of the Stack.appExports file, rendered in full
(an empty class when the Stack declares no constants);
nullwhen the Stack has no such file.final - dartSourcePath → String?
-
AppExports.path of Stack.appExports, or
null.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tfJson
→ Map<
String, dynamic> -
JSON-serialisable map suitable for
dart:convert'sJsonEncoder. AllTfArg/TfRefinstances have been collapsed to scalars or${...}interpolation strings.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited