TfArgLiteral<T> class
final
Constructors
- TfArgLiteral(T value)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
final
Methods
-
encodeAs(
String attribute) → TfArg< Object?> -
Available on TfArg<
The argument value: each element's RefTo.encodeAs for a literal list, the value itself otherwise.List< , provided by the RefToList extensionRefTo< >R> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited