TfCollectionType class final
list(...), set(...) or map(...).
Properties
- element → TfType
-
final
- expression → String
-
The constraint as Terraform writes it, which is also its tf.json form.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited